==> ZenTaoPMS.biz7.0.php5.4_5.6.zip: zentaopms/extension/max/reviewissue/lang/zh-tw.php <==
<?php
$lang->reviewissue->common           = '評審問題';
$lang->reviewissue->issue            = '問題列表';
$lang->reviewissue->issueBrowse      = '評審問題列表';
$lang->reviewissue->create           = '添加問題';
$lang->reviewissue->edit             = '編輯';
$lang->reviewissue->view             = '問題詳情';
$lang->reviewissue->updateStatus     = '更新問題狀態';
$lang->reviewissue->confirmSolve     = '確認該問題已解決？';
$lang->reviewissue->confirmActive    = '確認該問題重新激活？';
$lang->reviewissue->confirmClose     = '確認該問題需要關閉？';
$lang->reviewissue->resolved         = '解決';
$lang->reviewissue->activation       = '激活';
$lang->reviewissue->close            = '關閉';
$lang->reviewissue->issueInfo        = '問題詳情';
$lang->reviewissue->hasResolved      = '問題是否解決';
$lang->reviewissue->searchReview     = '選擇評審項';
$lang->reviewissue->injection        = '注入階段';

$lang->reviewissue->review      = '評審';
$lang->reviewissue->listID      = '檢查單';
$lang->reviewissue->title       = '問題標題';
$lang->reviewissue->opinion     = '問題意見';
$lang->reviewissue->status      = '狀態';
$lang->reviewissue->type        = '類型';
$lang->reviewissue->createdBy   = '創建人';
$lang->reviewissue->createdDate = '創建日期';

$lang->reviewissue->issueType['review']  = '評審問題';
$lang->reviewissue->issueType['audit']   = '審計問題';

$lang->reviewissue->statusList['active']   = '待解決';
$lang->reviewissue->statusList['resolved'] = '已解決';
$lang->reviewissue->statusList['closed']   = '已關閉';

$lang->reviewissue->browseStatus['all']       = '全部';
$lang->reviewissue->browseStatus['active']    = '待解決';
$lang->reviewissue->browseStatus['resolved']  = '已解決';
$lang->reviewissue->browseStatus['closed']    = '已關閉';
$lang->reviewissue->browseStatus['createdBy'] = '由我創建';
$lang->reviewissue->browseStatus['review']    = '評審問題';
$lang->reviewissue->browseStatus['audit']     = '審計問題';

$lang->reviewissue->review     = '評審項';
$lang->reviewissue->checklist  = '檢查單';
$lang->reviewissue->listType   = '檢查單分類';
$lang->reviewissue->resolution = '解決方案';

$lang->reviewissue->resolutionList['']           = '';
$lang->reviewissue->resolutionList['bydesign']   = '設計如此';
$lang->reviewissue->resolutionList['duplicate']  = '重複問題';
$lang->reviewissue->resolutionList['external']   = '外部原因';
$lang->reviewissue->resolutionList['fixed']      = '已解決';
$lang->reviewissue->resolutionList['notrepro']   = '無法重現';
$lang->reviewissue->resolutionList['postponed']  = '延期處理';
$lang->reviewissue->resolutionList['willnotfix'] = "不予解決";

==> ZenTaoPMS.biz8.0.php7.1.zip: zentaopms/extension/max/reviewissue/lang/zh-tw.php <==
<?php
$lang->reviewissue->common           = '評審問題';
$lang->reviewissue->issue            = '問題列表';
$lang->reviewissue->issueBrowse      = '評審問題列表';
$lang->reviewissue->create           = '添加問題';
$lang->reviewissue->edit             = '編輯';
$lang->reviewissue->view             = '問題詳情';
$lang->reviewissue->updateStatus     = '更新問題狀態';
$lang->reviewissue->confirmSolve     = '確認該問題已解決？';
$lang->reviewissue->confirmActive    = '確認該問題重新激活？';
$lang->reviewissue->confirmClose     = '確認該問題需要關閉？';
$lang->reviewissue->confirmDelete    = '確認該問題需要刪除？';
$lang->reviewissue->undeleteAction   = '該問題的所屬評審已被刪除，請先還原評審再還原問題';
$lang->reviewissue->resolved         = '解決';
$lang->reviewissue->activation       = '激活';
$lang->reviewissue->close            = '關閉';
$lang->reviewissue->delete           = '刪除';
$lang->reviewissue->deleted          = '已刪除';
$lang->reviewissue->issueInfo        = '問題詳情';
$lang->reviewissue->hasResolved      = '問題是否解決';
$lang->reviewissue->searchReview     = '選擇評審項';
$lang->reviewissue->injection        = '注入階段';

$lang->reviewissue->review      = '評審';
$lang->reviewissue->listID      = '檢查單';
$lang->reviewissue->title       = '問題標題';
$lang->reviewissue->opinion     = '問題意見';
$lang->reviewissue->status      = '狀態';
$lang->reviewissue->type        = '類型';
$lang->reviewissue->createdBy   = '創建人';
$lang->reviewissue->createdDate = '創建日期';

$lang->reviewissue->issueType['review']  = '評審問題';
$lang->reviewissue->issueType['audit']   = '審計問題';

$lang->reviewissue->statusList['active']   = '待解決';
$lang->reviewissue->statusList['resolved'] = '已解決';
$lang->reviewissue->statusList['closed']   = '已關閉';

$lang->reviewissue->browseStatus['all']       = '全部';
$lang->reviewissue->browseStatus['active']    = '待解決';
$lang->reviewissue->browseStatus['resolved']  = '已解決';
$lang->reviewissue->browseStatus['closed']    = '已關閉';
$lang->reviewissue->browseStatus['createdBy'] = '由我創建';
$lang->reviewissue->browseStatus['review']    = '評審問題';
$lang->reviewissue->browseStatus['audit']     = '審計問題';

$lang->reviewissue->review     = '評審項';
$lang->reviewissue->checklist  = '檢查單';
$lang->reviewissue->listType   = '檢查單分類';
$lang->reviewissue->resolution = '解決方案';

$lang->reviewissue->resolutionList['']           = '';
$lang->reviewissue->resolutionList['bydesign']   = '設計如此';
$lang->reviewissue->resolutionList['duplicate']  = '重複問題';
$lang->reviewissue->resolutionList['external']   = '外部原因';
$lang->reviewissue->resolutionList['fixed']      = '已解決';
$lang->reviewissue->resolutionList['notrepro']   = '無法重現';
$lang->reviewissue->resolutionList['postponed']  = '延期處理';
$lang->reviewissue->resolutionList['willnotfix'] = "不予解決";
